@@ -22,6 +22,7 @@ if TYPE_CHECKING:
     from cvxpy.atoms.atom import Atom
 
 import numbers
+import warnings
 
 import numpy as np
 import numpy.linalg as LA
@@ -36,6 +37,7 @@ from cvxpy.settings import (
     PSD_NSD_PROJECTION_TOL,
     SPARSE_PROJECTION_TOL,
 )
+from cvxpy.utilities.coo_array_compat import get_coords
 
 
 class Leaf(expression.Expression):
@@ -144,7 +146,7 @@ class Leaf(expression.Expression):
         if sparsity:
             self.sparse_idx = self._validate_indices(sparsity)
         else:
-            self.sparse_idx = []
+            self.sparse_idx = None
         # Only one attribute be True (except can be boolean and integer).
         true_attr = sum(1 for k, v in self.attributes.items() if v)
         # HACK we should remove this feature or allow multiple attributes in general.
@@ -157,35 +159,47 @@ class Leaf(expression.Expression):
             self.value = value
 
         self.args = []
-        self.bounds = bounds
+        self.bounds = self._ensure_valid_bounds(bounds)
 
-    def _validate_indices(self, indices: list[tuple[int]] | tuple[np.ndarray]) -> None:
+    def _validate_indices(self, indices: list[tuple[int]] | tuple[np.ndarray]) -> tuple[np.ndarray]:
         """
         Validate the sparsity pattern for a leaf node.
-    
+
         Parameters:
         indices: List or tuple of indices indicating the positions of non-zero elements.
         """
-        if not all(len(idx) == len(indices[0]) for idx in indices):
-            raise ValueError("All index tuples in indices must have the same length.")
-        
-        if len(indices) != len(self._shape):
-            raise ValueError(f"Indices should have {len(self._shape)} dimensions.")
-        
-        # convert list/tuple to array to validate indices within bounds
-        indices = np.array(indices)
+        if self._shape == ():
+            if indices != []:
+                raise ValueError("Indices should have 0 dimensions.")
+            return []
+        # Attempt to form a COO_array with the indices matrix provided;
+        # this will raise errors if invalid.
+        validator = sp.coo_array((np.empty(len(indices[0])), indices), shape=self._shape)
+        # Apply an in-place transformation to the coordinates to reduce the
+        # validator to canonical form
+        validator.sum_duplicates()
+        # Return the canonicalized coordinates
+        return get_coords(validator)
 
-        if np.any(indices < 0) or np.any(indices >= np.array(self._shape).reshape(-1, 1)):
-            raise ValueError(
-                f"Indices are out of bounds for expression with shape {self._shape}.")
-        return tuple(indices)
-    
     def _get_attr_str(self) -> str:
         """Get a string representing the attributes."""
         attr_str = ""
         for attr, val in self.attributes.items():
-            if attr != 'real' and val:
-                attr_str += ", %s=%s" % (attr, val)
+            if val is not False and val is not None:
+                if isinstance(val, bool):
+                    attr_str += ", %s=%s" % (attr, val)
+                elif attr == 'bounds' and val is not None:
+                    lower = np.array2string(val[0],
+                                    edgeitems=s.PRINT_EDGEITEMS,
+                                    threshold=s.PRINT_THRESHOLD,
+                                    formatter={'float': lambda x: f'{x:.2f}'})
+                    upper = np.array2string(val[1],
+                                    edgeitems=s.PRINT_EDGEITEMS,
+                                    threshold=s.PRINT_THRESHOLD,
+                                    formatter={'float': lambda x: f'{x:.2f}'})
+                    attr_str += ", %s=(%s, %s)" % (attr, lower, upper)
+                elif attr in ('sparsity', 'boolean', 'integer') and isinstance(val, Iterable):
+                    attr_str += ", %s=%s" % (attr, val)
         return attr_str
 
     def copy(self, args=None, id_objects=None):
@@ -311,7 +325,7 @@ class Leaf(expression.Expression):
         Parameters
         ----------
         term: The term to encode in the constraints.
-        constraints: An existing list of constraitns to append to.        
+        constraints: An existing list of constraitns to append to.
         """
         if self.attributes['nonneg'] or self.attributes['pos']:
             constraints.append(term >= 0)
@@ -355,7 +369,7 @@ class Leaf(expression.Expression):
             domain.append(self << 0)
         return domain
 
-    def project(self, val):
+    def project(self, val, sparse_path=False):
         """Project value onto the attribute set of the leaf.
 
         A sensible idiom is ``leaf.value = leaf.project(val)``.
@@ -423,32 +437,82 @@ class Leaf(expression.Expression):
                     return val
                 w[bad] = 0
             return (V * w).dot(V.T)
-        elif self.attributes['sparsity']:
+        elif self.attributes['sparsity'] and not sparse_path:
+            warnings.warn('Accessing a sparse CVXPY expression via a dense representation.'
+                          ' Please report this as a bug to the CVXPY Discord or GitHub.',
+                          RuntimeWarning, 3)
             new_val = np.zeros(self.shape)
-            new_val[self.sparse_idx] = val
+            new_val[self.sparse_idx] = val[self.sparse_idx]
             return new_val
         else:
             return val
 
     # Getter and setter for parameter value.
-    def save_value(self, val) -> None:
-        self._value = val
+    def save_value(self, val, sparse_path=False) -> None:
+        if val is None:
+            self._value = None
+        elif self.sparse_idx is not None and not sparse_path:
+            self._value = sp.coo_array((val[self.sparse_idx], self.sparse_idx), shape=self.shape)
+        elif self.sparse_idx is not None and sparse_path:
+            self._value = val.data
+        else:
+            self._value = val
 
     @property
     def value(self) -> Optional[np.ndarray]:
         """The numeric value of the expression."""
-        return self._value
+        if self.sparse_idx is None:
+            return self._value
+        else:
+            warnings.warn('Reading from a sparse CVXPY expression via `.value` is discouraged.'
+                          ' Use `.value_sparse` instead', RuntimeWarning, 1)
+            if self._value is None:
+                return None
+            val = np.zeros(self.shape)
+            val[self.sparse_idx] = self._value.data
+            return val
 
     @value.setter
     def value(self, val) -> None:
+        if self.sparse_idx is not None:
+            warnings.warn('Writing to a sparse CVXPY expression via `.value` is discouraged.'
+                          ' Use `.value_sparse` instead', RuntimeWarning, 1)
         self.save_value(self._validate_value(val))
 
+    @property
+    def value_sparse(self) -> Optional[...]:
+        """The numeric value of the expression if it is a sparse variable."""
+        if self._value is None:
+            return None
+        if isinstance(self._value, np.ndarray):
+            return sp.coo_array((self._value, self.sparse_idx), shape=self.shape)
+        else:
+            return self._value
+
+    @value_sparse.setter
+    def value_sparse(self, val) -> None:
+        if isinstance(val, sp.spmatrix):
+            val = sp.coo_array(val)
+        elif not isinstance(val, sp.coo_array):
+            if isinstance(val, (np.ndarray)) \
+                    and val.shape == (len(self.sparse_idx[0]),):
+                raise ValueError(
+                    'Invalid type for assigning value_sparse.'
+                    'Try using `'
+                    'expr.value_sparse = scipy.sparse.coo_array((values, expr)) instead.')
+            raise ValueError(
+                'Invalid type for assigning value_sparse.'
+                f'Recieved: {type(val)} Expected scipy.sparse.coo_array.'
+                f' Instantiate with scipy.sparse.coo_array((value_array, coordinates))'
+                )
+        self.save_value(self._validate_value(val, True), True)
+
     def project_and_assign(self, val) -> None:
         """Project and assign a value to the variable.
         """
         self.save_value(self.project(val))
 
-    def _validate_value(self, val):
+    def _validate_value(self, val, sparse_path=False):
         """Check that the value satisfies the leaf's symbolic attributes.
 
         Parameters
@@ -469,7 +533,16 @@ class Leaf(expression.Expression):
                     "Invalid dimensions %s for %s value." %
                     (intf.shape(val), self.__class__.__name__)
                 )
-            projection = self.project(val)
+            if sparse_path:
+                val.sum_duplicates()
+                coords_val = get_coords(val)
+                if len(coords_val) != len(self.sparse_idx) or \
+                     any((a != b).any() for a, b in zip(coords_val, self.sparse_idx)):
+                    raise ValueError(
+                        'Invalid sparsity pattern %s for %s value.' %
+                        (get_coords(val), self.__class__.__name__)
+                    )
+            projection = self.project(val, sparse_path)
             # ^ might be a numpy array, or sparse scipy matrix.
             delta = np.abs(val - projection)
             # ^ might be a numpy array, scipy matrix, or sparse scipy matrix.
@@ -503,6 +576,8 @@ class Leaf(expression.Expression):
                     attr_str = 'nonpositive'
                 elif self.attributes['neg']:
                     attr_str = 'negative'
+                elif self.attributes['sparsity']:
+                    attr_str = 'zero outside of sparsity pattern'
                 elif self.attributes['diag']:
                     attr_str = 'diagonal'
                 elif self.attributes['PSD']:
@@ -554,15 +629,9 @@ class Leaf(expression.Expression):
     def atoms(self) -> list[Atom]:
         return []
 
-    @property
-    def bounds(self):
-        return self._bounds
-
-    @bounds.setter
-    def bounds(self, value):
+    def _ensure_valid_bounds(self, value) -> Iterable | None:
         # In case for a constant or no bounds
         if value is None:
-            self._bounds = None
             return
 
         # Check that bounds is an iterable of two items
@@ -586,6 +655,13 @@ class Leaf(expression.Expression):
             elif np.isscalar(val):
                 value[idx] = np.full(self.shape, val)
 
+        # Upper bound cannot be -np.inf.
+        if np.any(value[1] == -np.inf):
+            raise ValueError("-np.inf is not feasible as an upper bound.")
+        # Lower bound cannot be np.inf.
+        if np.any(value[0] == np.inf):
+            raise ValueError("np.inf is not feasible as a lower bound.")
+
         # Check that upper_bound >= lower_bound
         if np.any(value[0] > value[1]):
             raise ValueError("Invalid bounds: some upper bounds are less "
@@ -595,11 +671,4 @@ class Leaf(expression.Expression):
             raise ValueError("np.nan is not feasible as lower "
                                 "or upper bound.")
 
-        # Upper bound cannot be -np.inf.
-        if np.any(value[1] == -np.inf):
-            raise ValueError("-np.inf is not feasible as an upper bound.")
-        # Lower bound cannot be np.inf.
-        if np.any(value[0] == np.inf):
-            raise ValueError("np.inf is not feasible as a lower bound.")
-
-        self._bounds = value
+        return value
