@@ -43,7 +43,10 @@ from cvxpy.reductions.reduction import Reduction
 from cvxpy.reductions.solvers import defines as slv_def
 from cvxpy.reductions.solvers.constant_solver import ConstantSolver
 from cvxpy.reductions.solvers.solver import Solver
-from cvxpy.settings import CLARABEL, ECOS, PARAM_THRESHOLD
+from cvxpy.settings import (
+    CLARABEL,
+    PARAM_THRESHOLD,
+)
 from cvxpy.utilities.debug_tools import build_non_disciplined_error_msg
 
 DPP_ERROR_MSG = (
@@ -58,21 +61,24 @@ ECOS_DEP_DEPRECATION_MSG = (
     """
     You specified your problem should be solved by ECOS. Starting in
     CXVPY 1.6.0, ECOS will no longer be installed by default with CVXPY.
-    Please either add an explicit dependency on ECOS or switch to our new
-    default solver, Clarabel, by either not specifying a solver argument
-    or specifying ``solver=cp.CLARABEL``.
+    Please either add ECOS as an explicit install dependency to your project
+    or switch to our new default solver, Clarabel, by either not specifying a
+    solver argument or specifying ``solver=cp.CLARABEL``. To suppress this
+    warning while continuing to use ECOS, you can filter this warning using
+    Python's ``warnings`` module until you are using 1.6.0.
     """
 )
 
 ECOS_DEPRECATION_MSG = (
     """
-    Your problem is being solved with the ECOS solver by default. Starting in 
-    CVXPY 1.5.0, Clarabel will be used as the default solver instead. To continue 
-    using ECOS, specify the ECOS solver explicitly using the ``solver=cp.ECOS`` 
+    Your problem is being solved with the ECOS solver by default. Starting in
+    CVXPY 1.5.0, Clarabel will be used as the default solver instead. To continue
+    using ECOS, specify the ECOS solver explicitly using the ``solver=cp.ECOS``
     argument to the ``problem.solve`` method.
     """
 )
 
+
 def _is_lp(self):
     """Is problem a linear program?
     """
@@ -154,7 +160,7 @@ def _reductions_for_problem_class(problem, candidates, gp: bool = False, solver_
     if type(problem.objective) == Maximize:
         reductions += [FlipObjective()]
 
-    # Special reduction for finite set constraint, 
+    # Special reduction for finite set constraint,
     # used by both QP and conic pathways.
     constr_types = {type(c) for c in problem.constraints}
     if FiniteSet in constr_types:
@@ -255,7 +261,7 @@ def construct_solving_chain(problem, candidates,
         solver = candidates['qp_solvers'][0]
         solver_instance = slv_def.SOLVER_MAP_QP[solver]
         reductions += [
-            CvxAttr2Constr(reduce_bounds=not solver_instance.BOUNDED_VARIABLES), 
+            CvxAttr2Constr(reduce_bounds=not solver_instance.BOUNDED_VARIABLES),
             qp2symbolic_qp.Qp2SymbolicQp(),
             QpMatrixStuffing(canon_backend=canon_backend),
             solver_instance,
@@ -350,10 +356,6 @@ def construct_solving_chain(problem, candidates,
                 CvxAttr2Constr(reduce_bounds=not solver_instance.BOUNDED_VARIABLES),
             ]
             if all(c in supported_constraints for c in cones):
-                if solver == ECOS and specified_solver == ECOS:
-                    warnings.warn(ECOS_DEP_DEPRECATION_MSG, FutureWarning)
-                elif solver == ECOS and specified_solver is None:
-                    warnings.warn(ECOS_DEPRECATION_MSG, FutureWarning)
                 # Return the reduction chain.
                 reductions += [
                     ConeMatrixStuffing(quad_obj=quad_obj, canon_backend=canon_backend),
