@@ -326,7 +326,7 @@ class TestConstraints(BaseTest):
             con = PowConeND(W, z, alpha.reshape((n, 1)))
         with self.assertRaises(ValueError):
             # wrong axis
-            con = PowConeND(reshape_atom(W, (n, 1)), z,
+            con = PowConeND(reshape_atom(W, (n, 1), order='F'), z,
                             alpha.reshape((n, 1)),
                             axis=1)
         # Compute a violation
@@ -363,7 +363,7 @@ class TestConstraints(BaseTest):
         c = np.arange(3)
         prob = cp.Problem(cp.Minimize(cp.sum(x)),
                           [cp.NonNeg(x - c)])
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertItemsAlmostEqual(x.value, c)
         prob.solve(solver=cp.OSQP)
         self.assertItemsAlmostEqual(x.value, c)
@@ -375,7 +375,7 @@ class TestConstraints(BaseTest):
         x = cp.Variable(3)
         c = np.arange(3)
         prob = cp.Problem(cp.Maximize(cp.sum(x)), [cp.NonPos(x - c)])
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertItemsAlmostEqual(x.value, c)
         prob.solve(solver=cp.OSQP)
         self.assertItemsAlmostEqual(x.value, c)
@@ -386,12 +386,12 @@ class TestConstraints(BaseTest):
         c = np.arange(3)
         objective = cp.Minimize(cp.sum(x))
         prob = cp.Problem(objective, [c - x <= 0])
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         dual = prob.constraints[0].dual_value
         # reported dual variables are the same with NonNeg, even though
         # the convention for how they add to the Lagrangian differs by sign.
         prob = cp.Problem(objective, [cp.NonNeg(x - c)])
-        prob.solve(solver=cp.ECOS)
+        prob.solve(solver=cp.CLARABEL)
         self.assertItemsAlmostEqual(prob.constraints[0].dual_value, dual)
         prob.solve(solver=cp.OSQP)
         self.assertItemsAlmostEqual(prob.constraints[0].dual_value, dual)
@@ -405,6 +405,44 @@ class TestConstraints(BaseTest):
         assert cp.Variable(bounds=[1, 2])._has_lower_bounds()
         assert cp.Variable(bounds=[1, 2])._has_upper_bounds()
 
+    def test_broadcasting(self) -> None:
+        """Test interaction of constraints and broadcasting."""
+        x = cp.Variable((3, 1))
+        c = cp.Constant(np.ones(3))
+        # Equality constraint.
+        con = (x == c)
+        assert con.shape == (3, 3)
+        prob = cp.Problem(cp.Minimize(0), [con])
+        prob.solve(solver=cp.CLARABEL) 
+        assert np.allclose(x.value, c.value)
+
+        with pytest.raises(ValueError, match="The CPP backend cannot be used"):
+            prob = cp.Problem(cp.Minimize(0), [con])
+            prob.solve(solver=cp.CLARABEL, canon_backend=cp.CPP_CANON_BACKEND) 
+
+        # Test QP codepath.
+        prob = cp.Problem(cp.Minimize(cp.sum_squares(x)), [con])
+        prob.solve(solver=cp.OSQP) 
+        assert np.allclose(x.value, c.value)
+
+        with pytest.raises(ValueError, match="The CPP backend cannot be used"):
+            prob = cp.Problem(cp.Minimize(cp.sum_squares(x)), [con])
+            prob.solve(solver=cp.OSQP, canon_backend=cp.CPP_CANON_BACKEND) 
+
+        # Inequality constraint.
+        con = (x >= c)
+        assert con.shape == (3, 3)
+        prob = cp.Problem(cp.Minimize(cp.sum(x)), [con])
+        prob.solve(solver=cp.CLARABEL) 
+        assert np.allclose(x.value, c.value)
+
+        with pytest.raises(ValueError, match="The CPP backend cannot be used"):
+            prob = cp.Problem(cp.Minimize(cp.sum(x)), [con])
+            prob.solve(solver=cp.CLARABEL, canon_backend=cp.CPP_CANON_BACKEND) 
+
+        # TODO other constraints
+
+
     def test_bounds_attr(self) -> None:
         """Test that the bounds attribute for variables and parameters is set correctly.
         """
